/*
* Konnect - a network tool for connecting to Internet
*
* Copyright (C) 2004  Fredrik Edemar
*                     f_edemar@linux.se
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
* the Free Software Foundation; either version 2 of the License, or
* (at your option) any later version.
* 
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
* 
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*
*/
#ifndef _KONNECT_H_
#define _KONNECT_H_

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <kaction.h>
#include <kapp.h>
#include <kconfigdialog.h>
#include <kiconloader.h>
#include <klocale.h>
#include <kmainwindow.h>
#include <kpopupmenu.h>
#include <ksystemtray.h>
#include <qaction.h>
#include <qbuffer.h>
#include <qcolor.h>
#include <qsocket.h>
#include <qhttp.h>
#include <qtimer.h>


#include "dcopinterface.h"
#include "konnectwidgetdlg.h"
#include "kconnectionsettings.h"
#include "generalsettings.h"
#include "intervalsettings.h"

class Konnect;

class Konnect : public KMainWindow, public KonnectDCOPInterface
{
    Q_OBJECT
public:
    /**
     * Default Constructor
     */
    Konnect();
    ~Konnect();
     
    private:
    QColor const inne, ute;
    QPixmap icon_out, icon_in;
    KSystemTray *m_tray;
    KonnectWidgetDlg *m_dlg;
    QTimer *m_timer;
    bool m_showmsgbox;

    QSocket *mySocket;
    QBuffer buffer;
    QHttp http;
    QString password;
    QString user;
    int m_connectionType;
    QString m_loginServer;
    
    //Configuartion dialogs
    KConnectionSettings *m_connectionSettings;
    GeneralSettings *m_generalSettings;
    IntervalSettings *m_intervalSettings;
    KConfigDialog* m_settingsDialog;
    
    protected:
    void closeEvent( QCloseEvent *e );
    void setupActions();
    void doClosingThings(); //called before exit
    
    private slots:
    void log_in();
    void log_out();
    void slotQuit();
    bool isConnected();
    void loginDone ( bool ) ;
    void logoutDone(bool);
    void updateConfiguration();
    void optionsPreferences();
    void toggleStatusBar();
    void toggleToolBar();
    void closeConnection();
    void test_connection();
    void connectiontest_succeeded();
};


#endif // _KONNECT_H_
